==> Percept_15.2.3.2_RC.zip: PERCEPT-Body-Camera-French.md <==
## 15.2.3.2

- **Fiabilité accrue du streaming en direct** : La diffusion est désormais prise en charge sur un plus large éventail de configurations réseau, assurant une connectivité plus régulière dans des environnements variés.

## 15.2.2.10

- **Visibilité des mises à jour du micrologiciel** : Ajout de la prise en charge de l'affichage quasi en temps réel du statut des mises à jour du micrologiciel dans PERCEPT Cloud.
- **Processus de mise à jour du micrologiciel amélioré** : Les mises à jour du micrologiciel se déroulent désormais sans interruption lorsque l'appareil est connecté via LTE et que l'interface Wi-Fi est configurée en mode point d'accès, à condition que le niveau de batterie soit suffisant.
- **Compatibilité améliorée avec la recherche d'enregistrements ONVIF** : La caméra corporelle est désormais conforme à la spécification ONVIF Profile G, garantissant la compatibilité avec le service de recherche d'enregistrements.
- **Intégrité des enregistrements renforcée** : Lorsque la fonction "Enregistrement permanent" est activée par un administrateur, les enregistrements restent actifs et ne sont pas affectés par les actions des super-utilisateurs dans le Live Viewer.

## 15.2.1.4

- **Nouvelle option "Disable Shutdown"** : Une option "Disable Shutdown" a été ajoutée au menu de configuration :
  - Cette option est désactivée par défaut.
  - Lorsqu'elle est activée, la caméra ne peut pas être éteinte tant que l'option n'est pas désactivée.
  - Elle remplace et désactive le délai d'arrêt automatique.
- **Nouvelle option "Always Record"** : Une option "Always Record" a été introduite dans le menu de configuration :
  - Cette option est désactivée par défaut.
  - L'enregistrement démarre automatiquement au démarrage de l'appareil et s'arrête lorsqu'il est placé dans une station d'accueil PERCEPT.
  - L'enregistrement reprend automatiquement lorsque l'appareil est retiré de la station d'accueil.
  - Le mode confidentialité a priorité sur cette option et interrompt l'enregistrement lorsqu'il est activé.

## 15.2.0.26

- **Amélioration de l'intégration des appareils** : Les appareils supprimés puis réintégrés dans PERCEPT Cloud se reconnectent désormais avec succès en moins de 5 minutes. Cela garantit un processus d'intégration fiable et ininterrompu pour la gestion des appareils.

## 15.2.0.18

- **Rapports précis sur l'état LTE** : L'état LTE reflète désormais la situation actuelle de la connexion LTE, y compris l'opérateur, la puissance du signal et le statut de la carte SIM, offrant une visibilité fiable dans PERCEPT Cloud.

## 15.2.0.16

- **Indexation plus rapide des archives vidéo** : Le processus d'indexation des archives vidéo a été optimisé, permettant un accès plus rapide aux enregistrements et réduisant les délais lors de leur récupération.
- **Indexation complète des fichiers** : Tous les fichiers présents sur la carte SD sont désormais indexés lors du processus de reconstruction, évitant ainsi les interruptions d'enregistrement causées par des fichiers non indexés.

## 15.2.0.6

- **Modèles de configuration simplifiés** : La prise en charge de plusieurs modèles a été désactivée, limitant chaque appareil à un seul modèle. Cela garantit un comportement cohérent et fiable lors de la gestion des modèles de configuration.
- **Fiabilité de l'onglet Intégrations** : L'onglet Intégrations charge désormais correctement son contenu dans toutes les configurations prises en charge, garantissant un accès fluide et une gestion efficace des intégrations.
- **Reconnexion automatique du VPN** : Les connexions VPN se reconnectent automatiquement en cas de déconnexion, maintenant une connectivité continue sans intervention manuelle.
- **Configuration VPN persistante** : Les configurations VPN restent opérationnelles après les mises à jour du micrologiciel, éliminant le besoin de reconfiguration et garantissant une connectivité ininterrompue.

==> Percept_15.2.4.22_RC.zip: PERCEPT-Body-Camera-French.md <==
## 15.2.4.22

- **Connectivité améliorée** : La connexion entre la Caméra d'intervention PERCEPT et PERCEPT Cloud reste stable et cohérente, même en cas de bande passante limitée ou après des transitions réseau.
- **Stabilité améliorée du streaming en direct** : Le streaming en temps réel dans PERCEPT Cloud est désormais plus fiable en cas de connectivité limitée ou après un changement de réseau.

## 15.2.3.2

- **Fiabilité accrue du streaming en direct** : La diffusion est désormais prise en charge sur un plus large éventail de configurations réseau, assurant une connectivité plus régulière dans des environnements variés.

## 15.2.2.10

- **Visibilité des mises à jour du micrologiciel** : Ajout de la prise en charge de l'affichage quasi en temps réel du statut des mises à jour du micrologiciel dans PERCEPT Cloud.
- **Processus de mise à jour du micrologiciel amélioré** : Les mises à jour du micrologiciel se déroulent désormais sans interruption lorsque l'appareil est connecté via LTE et que l'interface Wi-Fi est configurée en mode point d'accès, à condition que le niveau de batterie soit suffisant.
- **Compatibilité améliorée avec la recherche d'enregistrements ONVIF** : La caméra corporelle est désormais conforme à la spécification ONVIF Profile G, garantissant la compatibilité avec le service de recherche d'enregistrements.
- **Intégrité des enregistrements renforcée** : Lorsque la fonction "Enregistrement permanent" est activée par un administrateur, les enregistrements restent actifs et ne sont pas affectés par les actions des super-utilisateurs dans le Live Viewer.

## 15.2.1.4

- **Nouvelle option "Disable Shutdown"** : Une option "Disable Shutdown" a été ajoutée au menu de configuration :
  - Cette option est désactivée par défaut.
  - Lorsqu'elle est activée, la caméra ne peut pas être éteinte tant que l'option n'est pas désactivée.
  - Elle remplace et désactive le délai d'arrêt automatique.
- **Nouvelle option "Always Record"** : Une option "Always Record" a été introduite dans le menu de configuration :
  - Cette option est désactivée par défaut.
  - L'enregistrement démarre automatiquement au démarrage de l'appareil et s'arrête lorsqu'il est placé dans une station d'accueil PERCEPT.
  - L'enregistrement reprend automatiquement lorsque l'appareil est retiré de la station d'accueil.
  - Le mode confidentialité a priorité sur cette option et interrompt l'enregistrement lorsqu'il est activé.

## 15.2.0.26

- **Amélioration de l'intégration des appareils** : Les appareils supprimés puis réintégrés dans PERCEPT Cloud se reconnectent désormais avec succès en moins de 5 minutes. Cela garantit un processus d'intégration fiable et ininterrompu pour la gestion des appareils.

## 15.2.0.18

- **Rapports précis sur l'état LTE** : L'état LTE reflète désormais la situation actuelle de la connexion LTE, y compris l'opérateur, la puissance du signal et le statut de la carte SIM, offrant une visibilité fiable dans PERCEPT Cloud.

## 15.2.0.16

- **Indexation plus rapide des archives vidéo** : Le processus d'indexation des archives vidéo a été optimisé, permettant un accès plus rapide aux enregistrements et réduisant les délais lors de leur récupération.
- **Indexation complète des fichiers** : Tous les fichiers présents sur la carte SD sont désormais indexés lors du processus de reconstruction, évitant ainsi les interruptions d'enregistrement causées par des fichiers non indexés.

## 15.2.0.6

- **Modèles de configuration simplifiés** : La prise en charge de plusieurs modèles a été désactivée, limitant chaque appareil à un seul modèle. Cela garantit un comportement cohérent et fiable lors de la gestion des modèles de configuration.
- **Fiabilité de l'onglet Intégrations** : L'onglet Intégrations charge désormais correctement son contenu dans toutes les configurations prises en charge, garantissant un accès fluide et une gestion efficace des intégrations.
- **Reconnexion automatique du VPN** : Les connexions VPN se reconnectent automatiquement en cas de déconnexion, maintenant une connectivité continue sans intervention manuelle.
- **Configuration VPN persistante** : Les configurations VPN restent opérationnelles après les mises à jour du micrologiciel, éliminant le besoin de reconfiguration et garantissant une connectivité ininterrompue.
